@@ -3,7 +3,7 @@
   array.c -
 
   $Author: matz $
-  $Date: 1999/02/24 04:31:17 $
+  $Date: 1999/02/25 06:39:02 $
   created at: Fri Aug  6 09:46:12 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -194,7 +194,7 @@ rb_ary_s_new(argc, argv, klass)
     ary->ptr = ALLOC_N(VALUE, ary->capa);
     memfill(ary->ptr, len, val);
     ary->len = len;
-    rb_obj_call_init((VALUE)ary);
+    rb_obj_call_init((VALUE)ary, argc, argv);
 
     return (VALUE)ary;
 }
