@@ -8,15 +8,13 @@
 #include "ruby.h"
 #include "rubysig.h"
 
-VALUE mReadline;
-static VALUE histary;
-
-static ID id_completion_proc;
-static ID id_completion_case_fold;
-static ID id_call;
+static VALUE mReadline;
 
 #define TOLOWER(c) (isupper(c) ? tolower(c) : c)
 
+#define COMPLETION_PROC "completion_proc"
+#define COMPLETION_CASE_FOLD "completion_case_fold"
+
 static int
 readline_event()
 {
@@ -34,8 +32,7 @@ readline_readline(int argc, VALUE *argv, VALUE self)
     char *buff;
 
     if (rb_scan_args(argc, argv, "02", &tmp, &add_hist) > 0) {
-	Check_Type(tmp, T_STRING);
-	prompt = RSTRING(tmp)->ptr;
+	prompt = STR2CSTR(tmp);
     }
     buff = readline(prompt);
     if (RTEST(add_hist) && buff) {
@@ -52,27 +49,27 @@ readline_readline(int argc, VALUE *argv, VALUE self)
 static VALUE
 readline_s_set_completion_proc(VALUE self, VALUE proc)
 {
-    if (proc != Qnil && !rb_obj_is_instance_of(proc, rb_cProc))
-	rb_raise(rb_eArgError, "argument needs to be proc or nil");
-    return rb_ivar_set(mReadline, id_completion_proc, proc);
+    if (!rb_respond_to(proc, rb_intern("call")))
+	rb_raise(rb_eArgError, "argument have to respond to `call'");
+    return rb_iv_set(mReadline, COMPLETION_PROC, proc);
 }
 
 static VALUE
 readline_s_get_completion_proc(VALUE self)
 {
-    return rb_ivar_get(mReadline, id_completion_proc);
+    return rb_iv_get(mReadline, COMPLETION_PROC);
 }
 
 static VALUE
 readline_s_set_completion_case_fold(VALUE self, VALUE val)
 {
-    return rb_ivar_set(mReadline, id_completion_case_fold, val);
+    return rb_iv_set(mReadline, COMPLETION_CASE_FOLD, val);
 }
 
 static VALUE
 readline_s_get_completion_case_fold(VALUE self)
 {
-    return rb_ivar_get(mReadline, id_completion_case_fold);
+    return rb_iv_get(mReadline, COMPLETION_CASE_FOLD);
 }
 
 static char **
@@ -83,26 +80,19 @@ readline_attempted_completion_function(char *text, int start, int end)
     int case_fold;
     int i, matches;
 
-    proc = rb_ivar_get(mReadline, id_completion_proc);
-    if (!rb_obj_is_instance_of(proc, rb_cProc))
-	return NULL;
+    proc = rb_iv_get(mReadline, COMPLETION_PROC);
     rl_attempted_completion_over = 1;
-    case_fold = RTEST(rb_ivar_get(mReadline, id_completion_case_fold));
-    ary = rb_funcall(proc, id_call, 1, rb_str_new2(text));
-    if (!rb_obj_is_instance_of(ary, rb_cArray))
-	return NULL;
+    case_fold = RTEST(rb_iv_get(mReadline, COMPLETION_CASE_FOLD));
+    ary = rb_funcall(proc, rb_intern("call"), 1, rb_str_new2(text));
+    if (TYPE(ary) != T_ARRAY)
+	ary = rb_Array(ary);
     matches = RARRAY(ary)->len;
     if (matches == 0)
 	return NULL;
-    result = (char **) xmalloc(sizeof(char *) * (matches + 2));
+    result = ALLOC_N(char *, matches + 2);
     for (i = 0; i < matches; i++) {
-	temp = RARRAY(ary)->ptr[i];
-	if (!rb_obj_is_instance_of(temp, rb_cString)) {
-	    if (result) free(result);
-	    return NULL;
-	}
-	result[i + 1]
-	    = (char *) xmalloc(sizeof(char) * (RSTRING(temp)->len + 1));
+	temp = rb_obj_as_string(RARRAY(ary)->ptr[i]);
+	result[i + 1] = ALLOC_N(char, RSTRING(temp)->len + 1);
 	strcpy(result[i + 1], RSTRING(temp)->ptr);
     }
     result[matches + 1] = NULL;
@@ -134,8 +124,8 @@ readline_attempted_completion_function(char *text, int start, int end)
 	    if (low > si) low = si;
 	    i++;
 	}
-	result[0] = xmalloc (low + 1);
-	strncpy (result[0], result[1], low);
+	result[0] = ALLOC_N(char, low + 1);
+	strncpy(result[0], result[1], low);
 	result[0][low] = '\0';
     }
 
@@ -187,16 +177,14 @@ hist_set(VALUE self, VALUE index, VALUE str)
     if (i < 0 || i > state->length - 1) {
 	rb_raise(rb_eIndexError, "Invalid index");
     }
-    Check_Type(str, T_STRING);
-    replace_history_entry(i, RSTRING(str)->ptr, NULL);
+    replace_history_entry(i, STR2CSTR(str), NULL);
     return str;
 }
 
 static VALUE
 hist_push(VALUE self, VALUE str)
 {
-    Check_Type(str, T_STRING);
-    add_history(RSTRING(str)->ptr);
+    add_history(STR2CSTR(str));
     return self;
 }
 
@@ -208,8 +196,7 @@ hist_push_method(int argc, VALUE *argv,
     
     while (argc--) {
 	str = *argv++;
-	Check_Type(str, T_STRING);
-	add_history(RSTRING(str)->ptr);
+	add_history(STR2CSTR(str));
     }
     return self;
 }
@@ -294,14 +281,60 @@ hist_delete_at(VALUE self, VALUE index)
     return rb_str_new2(entry->line);
 }
 
+static VALUE
+filename_completion_proc_call(VALUE self, VALUE str)
+{
+    VALUE result;
+    char **matches;
+    int i;
+
+    matches = completion_matches(STR2CSTR(str),
+				 filename_completion_function);
+    if (matches) {
+	result = rb_ary_new();
+	for (i = 0; matches[i]; i++) {
+	    rb_ary_push(result, rb_str_new2(matches[i]));
+	    free(matches[i]);
+	}
+	free(matches);
+	if (RARRAY(result)->len >= 2)
+	    rb_ary_shift(result);
+    }
+    else {
+	result = Qnil;
+    }
+    return result;
+}
+
+static VALUE
+username_completion_proc_call(VALUE self, VALUE str)
+{
+    VALUE result;
+    char **matches;
+    int i;
+
+    matches = completion_matches(STR2CSTR(str),
+				 username_completion_function);
+    if (matches) {
+	result = rb_ary_new();
+	for (i = 0; matches[i]; i++) {
+	    rb_ary_push(result, rb_str_new2(matches[i]));
+	    free(matches[i]);
+	}
+	free(matches);
+	if (RARRAY(result)->len >= 2)
+	    rb_ary_shift(result);
+    }
+    else {
+	result = Qnil;
+    }
+    return result;
+}
+
 void
 Init_readline(void)
 {
-    extern VALUE rb_mEnumerable;
-
-    id_completion_proc = rb_intern("completion_proc");
-    id_completion_case_fold = rb_intern("completion_case_fold");
-    id_call = rb_intern("call");
+    VALUE histary, fcomp, ucomp;
 
     using_history();
 
@@ -336,6 +369,16 @@ Init_readline(void)
     rb_define_singleton_method(histary,"delete_at", hist_delete_at, 1);
     rb_define_const(mReadline, "HISTORY", histary);
 
+    fcomp = rb_obj_alloc(rb_cObject);
+    rb_define_singleton_method(fcomp, "call",
+			       filename_completion_proc_call, 1);
+    rb_define_const(mReadline, "FILENAME_COMPLETION_PROC", fcomp);
+
+    ucomp = rb_obj_alloc(rb_cObject);
+    rb_define_singleton_method(ucomp, "call",
+			       username_completion_proc_call, 1);
+    rb_define_const(mReadline, "USERNAME_COMPLETION_PROC", ucomp);
+
     rl_attempted_completion_function
 	= (CPPFunction *) readline_attempted_completion_function;
     rl_event_hook = readline_event;
