@@ -3,7 +3,7 @@
   socket.c -
 
   $Author: matz $
-  $Date: 1999/02/12 11:17:06 $
+  $Date: 1999/02/25 06:39:12 $
   created at: Thu Mar 31 12:21:29 JST 1994
 
 ************************************************/
@@ -102,7 +102,7 @@ sock_new(class, fd)
     fp->f2 = rb_fdopen(fd, "w");
     fp->mode = FMODE_READWRITE;
     rb_io_unbuffered(fp);
-    rb_obj_call_init((VALUE)sock);
+    rb_obj_call_init((VALUE)sock, 0, 0);
 
     return (VALUE)sock;
 }
