@@ -3,7 +3,7 @@
   file.c -
 
   $Author: matz $
-  $Date: 1999/02/24 04:31:20 $
+  $Date: 1999/02/25 06:39:07 $
   created at: Mon Nov 15 12:24:34 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -1363,7 +1363,7 @@ test_check(n, argc, argv)
     int i;
 
     n+=1;
-    if (n < argc) rb_raise(rb_eArgError, "Wrong # of arguments(%d for %d)", argc, n);
+    if (n < argc) rb_raise(rb_eArgError, "wrong # of arguments(%d for %d)", argc, n);
     for (i=1; i<n; i++) {
 	switch (TYPE(argv[i])) {
 	  case T_STRING:
@@ -1387,7 +1387,7 @@ rb_f_test(argc, argv)
 {
     int cmd;
 
-    if (argc == 0) rb_raise(rb_eArgError, "Wrong # of arguments");
+    if (argc == 0) rb_raise(rb_eArgError, "wrong # of arguments");
     cmd = NUM2CHR(argv[0]);
     if (cmd == 0) return Qfalse;
     if (strchr("bcdefgGkloOprRsSuwWxXz", cmd)) {
