@@ -1,8 +1,8 @@
 #
-#   sync.rb - 2-եå饹
+#   sync.rb - 2 phase lock with counter
 #   	$Release Version: 0.2$
-#   	$Revision: 1.1.1.2.2.5 $
-#   	$Date: 1998/05/01 08:56:44 $
+#   	$Revision: 1.1.1.3.2.1 $
+#   	$Date: 1999/02/09 06:08:24 $
 #   	by Keiju ISHITSUKA
 #   	modified by matz
 #
@@ -47,14 +47,14 @@ end
 require "final"
 
 module Sync_m
-  RCS_ID='-$Header: /home/cvs/ruby/lib/sync.rb,v 1.1.1.2.2.5 1998/05/01 08:56:44 matz Exp $-'
+  RCS_ID='-$Header: /home/cvsroot/ruby/lib/sync.rb,v 1.1.1.3.2.1 1999/02/09 06:08:24 matz Exp $-'
   
   # lock mode
   UN = :UN
   SH = :SH
   EX = :EX
   
-  # 㳰
+  # exceptions
   class Err < StandardError
     def Err.Fail(*opt)
       fail self, sprintf(self::Message, *opt)
@@ -97,7 +97,7 @@ module Sync_m
       dummy = cl.new
       Sync_m.extendable_module(dummy)
     rescue NameError
-      # newƤʤ, DATAȤߤʤ.
+      # if new is not defined, cl must be Data.
       For_primitive_object
     end
   end
@@ -105,8 +105,8 @@ module Sync_m
   def Sync_m.extend_class(cl)
     return super if cl.instance_of?(Module)
     
-    # ⥸塼λϲ⤷ʤ. 饹ξ, Ŭڤʥ⥸塼η
-    # aliasԤ.  
+    # do nothing for Modules
+    # make aliases and include the proper module.
     real = includable_module(cl)
     cl.module_eval %q{
       include real
@@ -267,7 +267,7 @@ module Sync_m
 	sync_sh_locker[Thread.current] = count + 1
 	ret = TRUE
       when EX
-	# , ⡼ɤEXǤ, ɬEXåȤʤ.
+	# in EX mode, lock will upgrade to EX lock
 	if sync_ex_locker == Thread.current
 	  self.sync_ex_count = sync_ex_count + 1
 	  ret = TRUE
@@ -342,7 +342,7 @@ module Sync_m
     
     def For_primitive_object.sync_finalize(id)
       wait = Sync_Locked.delete(id)
-      # waiting == [] Ȥ GCΤ, Ԥβϰ̣ʤ.
+      # need not to free waiting
     end
     
     def sync_mode
