@@ -3,7 +3,7 @@
   process.c -
 
   $Author: matz $
-  $Date: 1999/02/24 04:31:23 $
+  $Date: 1999/02/25 06:39:10 $
   created at: Tue Aug 10 14:30:50 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -117,7 +117,7 @@ rb_waitpid(pid, flags, st)
     }
 
     if (flags) {
-	rb_raise(rb_eArgError, "Can't do waitpid with flags");
+	rb_raise(rb_eArgError, "can't do waitpid with flags");
     }
 
     for (;;) {
