@@ -3,20 +3,25 @@
   sprintf.c -
 
   $Author: matz $
-  $Date: 1999/05/14 08:56:47 $
+  $Date: 1999/02/15 07:31:51 $
   created at: Fri Oct 15 10:39:26 JST 1993
 
-  Copyright (C) 1993-1998 Yukihiro Matsumoto
+  Copyright (C) 1993-1999 Yukihiro Matsumoto
 
 ************************************************/
 
 #include "ruby.h"
 #include <ctype.h>
-#include <math.h>
 
-#define BIT_DIGITS(N)   (((N)*146)/485 + 1)  /* log2(10) =~ 146/485 */
+#ifndef atof
+double strtod();
+#endif
 
+#ifdef USE_CWGUSI
+static void fmt_setup();
+#else
 static void fmt_setup _((char*,char,int,int,int));
+#endif
 
 static char*
 remove_sign_bits(str, base)
@@ -103,7 +108,7 @@ remove_sign_bits(str, base)
     return str;
 }
 
-double big2dbl _((VALUE));
+double rb_big2dbl _((VALUE));
 
 #define FNONE  0
 #define FSHARP 1
@@ -128,10 +133,10 @@ double big2dbl _((VALUE));
 }
 
 #define GETARG() \
-    ((argc == 0)?(ArgError("too few argument."),0):(argc--,((argv++)[0])))
+    ((argc == 0)?(rb_raise(rb_eArgError, "too few argument."),0):(argc--,((argv++)[0])))
 
 VALUE
-f_sprintf(argc, argv)
+rb_f_sprintf(argc, argv)
     int argc;
     VALUE *argv;
 {
@@ -168,9 +173,9 @@ f_sprintf(argc, argv)
 	switch (*p) {
 	  default:
 	    if (ISPRINT(*p))
-		ArgError("malformed format string - %%%c", *p);
+		rb_raise(rb_eArgError, "malformed format string - %%%c", *p);
 	    else
-		ArgError("malformed format string");
+		rb_raise(rb_eArgError, "malformed format string");
 	    break;
 
 	  case ' ':
@@ -206,13 +211,13 @@ f_sprintf(argc, argv)
 		width = 10 * width + (*p - '0');
 	    }
 	    if (p >= end) {
-		ArgError("malformed format string - %%[0-9]");
+		rb_raise(rb_eArgError, "malformed format string - %%[0-9]");
 	    }
 	    goto retry;
 
 	  case '*':
 	    if (flags & FWIDTH) {
-		ArgError("width given twice");
+		rb_raise(rb_eArgError, "width given twice");
 	    }
 
 	    flags |= FWIDTH;
@@ -227,7 +232,7 @@ f_sprintf(argc, argv)
 
 	  case '.':
 	    if (flags & FPREC) {
-		ArgError("precision given twice");
+		rb_raise(rb_eArgError, "precision given twice");
 	    }
 
 	    prec = 0;
@@ -245,7 +250,7 @@ f_sprintf(argc, argv)
 		prec = 10 * prec + (*p - '0');
 	    }
 	    if (p >= end) {
-		ArgError("malformed format string - %%.[0-9]");
+		rb_raise(rb_eArgError, "malformed format string - %%.[0-9]");
 	    }
 	    if (prec > 0)
 		flags |= FPREC;
@@ -278,7 +283,7 @@ f_sprintf(argc, argv)
 		VALUE arg = GETARG();
 		int len;
 
-		str = obj_as_string(arg);
+		str = rb_obj_as_string(arg);
 		len = RSTRING(str)->len;
 		if (flags&FPREC) {
 		    if (prec < len) {
@@ -359,12 +364,12 @@ f_sprintf(argc, argv)
 		    v = FIX2LONG(val);
 		    break;
 		  case T_FLOAT:
-		    val = dbl2big(RFLOAT(val)->value);
+		    val = rb_dbl2big(RFLOAT(val)->value);
 		    if (FIXNUM_P(val)) goto bin_retry;
 		    bignum = 1;
 		    break;
 		  case T_STRING:
-		    val = str2inum(RSTRING(val)->ptr, 10);
+		    val = rb_str2inum(RSTRING(val)->ptr, 10);
 		    goto bin_retry;
 		  case T_BIGNUM:
 		    bignum = 1;
@@ -380,7 +385,7 @@ f_sprintf(argc, argv)
 		else if (*p == 'b') base = 2;
 		if (!bignum) {
 		    if (base == 2) {
-			val = int2big(v);
+			val = rb_int2big(v);
 			goto bin_retry;
 		    }
 		    if (sign) {
@@ -432,7 +437,7 @@ f_sprintf(argc, argv)
 		}
 
 		if (sign) {
-		    val = big2str(val, base);
+		    val = rb_big2str(val, base);
 		    s = RSTRING(val)->ptr;
 		    if (s[0] == '-') {
 			s++;
@@ -450,14 +455,14 @@ f_sprintf(argc, argv)
 		    goto format_integer;
 		}
 		if (!RBIGNUM(val)->sign) {
-		    val = big_clone(val);
-		    big_2comp(val);
+		    val = rb_big_clone(val);
+		    rb_big_2comp(val);
 		}
-		val = big2str(val, base);
+		val = rb_big2str(val, base);
 		s = RSTRING(val)->ptr;
 		if (*s == '-') {
 		    remove_sign_bits(++s, base);
-		    val = str_new(0, 3+strlen(s));
+		    val = rb_str_new(0, 3+strlen(s));
 		    t = RSTRING(val)->ptr;
 		    strcpy(t, "..");
 		    t += 2;
@@ -551,12 +556,12 @@ f_sprintf(argc, argv)
 
 	  case 'f':
 	  case 'g':
+	  case 'G':
 	  case 'e':
 	  case 'E':
 	    {
 		VALUE val = GETARG();
 		double fval;
-		int i, need = 6;
 		char fbuf[32];
 
 		switch (TYPE(val)) {
@@ -567,10 +572,10 @@ f_sprintf(argc, argv)
 		    fval = RFLOAT(val)->value;
 		    break;
 		  case T_BIGNUM:
-		    fval = big2dbl(val);
+		    fval = rb_big2dbl(val);
 		    break;
 		  case T_STRING:
-		    fval = atof(RSTRING(val)->ptr);
+		    fval = strtod(RSTRING(val)->ptr, 0);
 		    break;
 		  default:
 		    Check_Type(val, T_FLOAT);
@@ -579,19 +584,7 @@ f_sprintf(argc, argv)
 
 		fmt_setup(fbuf, *p, flags, width, prec);
 
-		need = 0;
-		if (*p != 'e' && *p != 'E') {
-		    i = INT_MIN;
-		    frexp(fval, &i);
-		    if (i > 0)
-			need = BIT_DIGITS(i);
-		}
-		need += (flags&FPREC) ? prec : 6;
-		if ((flags&FWIDTH) && need < width)
-		    need = width;
-		need += 20;
-
-		CHECK(need);
+		CHECK(22);
 		sprintf(&buf[blen], fbuf, fval);
 		blen += strlen(&buf[blen]);
 	    }
@@ -601,10 +594,10 @@ f_sprintf(argc, argv)
     }
 
   sprint_exit:
-    if (RTEST(verbose) && argc > 0) {
-	ArgError("too many argument for format string");
+    if (RTEST(ruby_verbose) && argc > 1) {
+	rb_raise(rb_eArgError, "too many argument for format string");
     }
-    result = str_new(buf, blen);
+    result = rb_str_new(buf, blen);
     free(buf);
 
     return result;
